3.0.1
=====

Require later lxml to avoid DeprecationWarning.

3.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

Drop support for Python 3.5 and earlier.

2.0
===

Drop support for Python 3.4 and earlier.

1.1
===

Moved hosting to GitHub. Refreshed package metadata.

1.0
===

Initial release.
